==> StudentGWAS_0.0.3.tar.gz: StudentGWAS/R/SQLiteFunctions.R <==
## function to retrieve subject data
getSubjects <- function(dbPath)
{
    drv <- SQLite()
    con <- dbConnect(drv, dbname=dbPath)
    sql <- "SELECT * FROM subjects"
    res <- dbGetQuery(con, sql)  
    dbDisconnect(con)
    res
}

## function to retrieve snp data
getSnps <- function(dbPath)
{
    drv <- SQLite()
    con <- dbConnect(drv, dbname=dbPath)
    sql <- "SELECT * FROM snps"
    res <- dbGetQuery(con, sql)
    dbDisconnect(con)
    res
}

## function to retrieve snp data joined with KEGG path IDs
getKEGGSnps <- function(dbPath)
{
    drv <- SQLite()
    con <- dbConnect(drv, dbname=dbPath)
    require("org.Hs.eg.db")
    orgPath <- system.file("extdata", "org.Hs.eg.sqlite",
                          package="org.Hs.eg.db")
    ## Attach the foreign db from the dbPath
    dbGetQuery(con, sprintf("ATTACH '%s' AS db", orgPath))
    ## Then use that in the query                                     
    sql <- "SELECT * FROM db.kegg AS k, db.genes as g, snps as s
            WHERE k._id=g._id AND g.gene_id=s.gene_id"
    res <- dbGetQuery(con, sql)
    dbDisconnect(con)
    res
}


## a test function (not exported)
## this function just returns TRUE if the local org package is the expected
## vintage
.checkKEGGMeta <- function(){
    drv <- SQLite()
    require("org.Hs.eg.db")
    con <- dbConnect(drv, dbname=system.file("extdata", "org.Hs.eg.sqlite", 
                                             package = "org.Hs.eg.db"))
    sql <- "SELECT value FROM metadata WHERE name='KEGGSOURCEDATE';"
    res <- dbGetQuery(con, sql)
    dbDisconnect(con)
    if (res=="2010-Sep7"){return(TRUE)}else{return(FALSE)}   
}

==> StudentGWAS_0.4.0.tar.gz: StudentGWAS/R/SQLiteFunctions.R <==
## function to retrieve subject data
getSubjects <- function(dbPath)
{
    drv <- SQLite()
    con <- dbConnect(drv, dbname=dbPath)
    sql <- "SELECT * FROM subjects ORDER BY id"
    res <- dbGetQuery(con, sql)  
    dbDisconnect(con)
    res
}

## function to retrieve snp data
getSnps <- function(dbPath)
{
    drv <- SQLite()
    con <- dbConnect(drv, dbname=dbPath)
    sql <- "SELECT * FROM snps ORDER BY id"
    res <- dbGetQuery(con, sql)
    dbDisconnect(con)
    res
}

## function to retrieve snp data joined with KEGG path IDs
getKEGGSnps <- function(dbPath)
{
    drv <- SQLite()
    con <- dbConnect(drv, dbname=dbPath)
    require("org.Hs.eg.db")
    orgPath <- system.file("extdata", "org.Hs.eg.sqlite",
                          package="org.Hs.eg.db")
    ## Attach the foreign db from the dbPath
    dbGetQuery(con, sprintf("ATTACH '%s' AS db", orgPath))
    ## Then use that in the query                                     
    sql <- "SELECT * FROM db.kegg AS k, db.genes as g, snps as s
            WHERE k._id=g._id AND g.gene_id=s.gene_id"
    res <- dbGetQuery(con, sql)
    dbDisconnect(con)
    res
}


## a test function (not exported)
## this function just returns TRUE if the local org package is the expected
## vintage
.checkKEGGMeta <- function(){
    drv <- SQLite()
    require("org.Hs.eg.db")
    con <- dbConnect(drv, dbname=system.file("extdata", "org.Hs.eg.sqlite", 
                                             package = "org.Hs.eg.db"))
    sql <- "SELECT value FROM metadata WHERE name='KEGGSOURCEDATE';"
    res <- dbGetQuery(con, sql)
    dbDisconnect(con)
    if (res=="2010-Sep7"){return(TRUE)}else{return(FALSE)}   
}
